@@ -414,6 +414,7 @@ types: list[str] = [
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
@@ -559,6 +560,7 @@ types: list[str] = [
     "AWS::RDS::GlobalCluster",
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -740,7 +742,6 @@ cached: list[str] = [
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -805,7 +806,6 @@ cached: list[str] = [
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-batch-computeenvironment.json",
-    "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-budgets-budget.json",
@@ -831,7 +831,6 @@ cached: list[str] = [
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-responseheaderspolicy.json",
@@ -1022,11 +1021,12 @@ cached: list[str] = [
     "aws-eventschemas-schema.json",
     "aws-fms-policy.json",
     "aws-fsx-datarepositoryassociation.json",
-    "aws-fsx-filesystem.json",
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
+    "aws-gamelift-alias.json",
     "aws-gamelift-build.json",
+    "aws-gamelift-fleet.json",
     "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-matchmakingconfiguration.json",
@@ -1105,6 +1105,7 @@ cached: list[str] = [
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
+    "aws-iot-command.json",
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
@@ -1173,12 +1174,8 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
-    "aws-logs-metricfilter.json",
-    "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
-    "aws-logs-subscriptionfilter.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
@@ -1223,7 +1220,7 @@ cached: list[str] = [
     "aws-quicksight-theme.json",
     "aws-quicksight-vpcconnection.json",
     "aws-ram-permission.json",
-    "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
