@@ -403,6 +403,7 @@ types: list[str] = [
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
@@ -516,6 +517,7 @@ types: list[str] = [
     "AWS::RDS::GlobalCluster",
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
+    "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -697,7 +699,6 @@ cached: list[str] = [
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -789,7 +790,6 @@ cached: list[str] = [
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-responseheaderspolicy.json",
@@ -927,13 +927,13 @@ cached: list[str] = [
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
-    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
     "aws-efs-mounttarget.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
+    "aws-eks-cluster.json",
     "aws-eks-identityproviderconfig.json",
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
@@ -963,7 +963,6 @@ cached: list[str] = [
     "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
     "aws-emr-studio.json",
-    "aws-emrserverless-application.json",
     "aws-events-archive.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
@@ -978,7 +977,9 @@ cached: list[str] = [
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
+    "aws-gamelift-alias.json",
     "aws-gamelift-build.json",
+    "aws-gamelift-fleet.json",
     "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-matchmakingconfiguration.json",
@@ -1039,6 +1040,7 @@ cached: list[str] = [
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
+    "aws-iot-command.json",
     "aws-iot-custommetric.json",
     "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
@@ -1087,12 +1089,8 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
-    "aws-logs-metricfilter.json",
-    "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
-    "aws-logs-subscriptionfilter.json",
     "aws-mediaconvert-jobtemplate.json",
     "aws-mediaconvert-preset.json",
     "aws-mediaconvert-queue.json",
@@ -1124,7 +1122,7 @@ cached: list[str] = [
     "aws-organizations-resourcepolicy.json",
     "aws-pipes-pipe.json",
     "aws-ram-permission.json",
-    "aws-ram-resourceshare.json",
+    "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
@@ -1150,7 +1148,6 @@ cached: list[str] = [
     "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
-    "aws-redshiftserverless-workgroup.json",
     "aws-resourcegroups-group.json",
     "aws-rolesanywhere-crl.json",
     "aws-rolesanywhere-profile.json",
@@ -1226,7 +1223,6 @@ cached: list[str] = [
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
-    "aws-servicediscovery-service.json",
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
